@@ -10,6 +10,9 @@ class UncheckedRequest (Exception, ) : pass
 class InvalidRequest (Exception, ) : pass
 
 
+class InvalidResponse (Exception, ) : pass
+
+
 class Disconnected (Exception, ) : pass
 
 
@@ -28,3 +31,6 @@ class ThisIsNotHeader (Exception, ) : pass
 class ThisIsNotValidHeader (Exception, ) : pass
 
 
+class StopReceiveData (Exception, ) : pass
+
+
